==> huaweicloudsdkrds-3.1.124-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/postgre_sql_restore_database.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PostgreSQLRestoreDatabase:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'database': 'str',
        'schemas': 'list[PostgreSQLRestoreSchema]'
    }

    attribute_map = {
        'database': 'database',
        'schemas': 'schemas'
    }

    def __init__(self, database=None, schemas=None):
        """PostgreSQLRestoreDatabase

        The model defined in huaweicloud sdk

        :param database: 数据库名
        :type database: str
        :param schemas: 模式信息
        :type schemas: list[:class:`huaweicloudsdkrds.v3.PostgreSQLRestoreSchema`]
        """
        
        

        self._database = None
        self._schemas = None
        self.discriminator = None

        if database is not None:
            self.database = database
        if schemas is not None:
            self.schemas = schemas

    @property
    def database(self):
        """Gets the database of this PostgreSQLRestoreDatabase.

        数据库名

        :return: The database of this PostgreSQLRestoreDatabase.
        :rtype: str
        """
        return self._database

    @database.setter
    def database(self, database):
        """Sets the database of this PostgreSQLRestoreDatabase.

        数据库名

        :param database: The database of this PostgreSQLRestoreDatabase.
        :type database: str
        """
        self._database = database

    @property
    def schemas(self):
        """Gets the schemas of this PostgreSQLRestoreDatabase.

        模式信息

        :return: The schemas of this PostgreSQLRestoreDatabase.
        :rtype: list[:class:`huaweicloudsdkrds.v3.PostgreSQLRestoreSchema`]
        """
        return self._schemas

    @schemas.setter
    def schemas(self, schemas):
        """Sets the schemas of this PostgreSQLRestoreDatabase.

        模式信息

        :param schemas: The schemas of this PostgreSQLRestoreDatabase.
        :type schemas: list[:class:`huaweicloudsdkrds.v3.PostgreSQLRestoreSchema`]
        """
        self._schemas = schemas

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PostgreSQLRestoreDatabase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrds-3.1.157-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/postgre_sql_restore_database.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PostgreSQLRestoreDatabase:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'database': 'str',
        'schemas': 'list[PostgreSQLRestoreSchema]'
    }

    attribute_map = {
        'database': 'database',
        'schemas': 'schemas'
    }

    def __init__(self, database=None, schemas=None):
        r"""PostgreSQLRestoreDatabase

        The model defined in huaweicloud sdk

        :param database: 数据库名
        :type database: str
        :param schemas: 模式信息
        :type schemas: list[:class:`huaweicloudsdkrds.v3.PostgreSQLRestoreSchema`]
        """
        
        

        self._database = None
        self._schemas = None
        self.discriminator = None

        if database is not None:
            self.database = database
        if schemas is not None:
            self.schemas = schemas

    @property
    def database(self):
        r"""Gets the database of this PostgreSQLRestoreDatabase.

        数据库名

        :return: The database of this PostgreSQLRestoreDatabase.
        :rtype: str
        """
        return self._database

    @database.setter
    def database(self, database):
        r"""Sets the database of this PostgreSQLRestoreDatabase.

        数据库名

        :param database: The database of this PostgreSQLRestoreDatabase.
        :type database: str
        """
        self._database = database

    @property
    def schemas(self):
        r"""Gets the schemas of this PostgreSQLRestoreDatabase.

        模式信息

        :return: The schemas of this PostgreSQLRestoreDatabase.
        :rtype: list[:class:`huaweicloudsdkrds.v3.PostgreSQLRestoreSchema`]
        """
        return self._schemas

    @schemas.setter
    def schemas(self, schemas):
        r"""Sets the schemas of this PostgreSQLRestoreDatabase.

        模式信息

        :param schemas: The schemas of this PostgreSQLRestoreDatabase.
        :type schemas: list[:class:`huaweicloudsdkrds.v3.PostgreSQLRestoreSchema`]
        """
        self._schemas = schemas

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PostgreSQLRestoreDatabase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
